# 

make_outcomes_table = function(data) {
  outcomes = list('integration_2025' = 'Likelihood of integration by 2025', 
                  'confidence_2025' = 'Confidence in answer to likelihood of integration by 2025',
                  'integration_2050' = 'Likelihood of integration by 2050',
                  'confidence_2050' = 'Confidence in answer to likelihood of integration by 2050',
                  'az_polbeliefs' = 'Index of political beliefs (z-score)', 
                  'democracy_nodiff' = 'Perceived importance of democracy', 
                  'pol_attitude' = 'Political attitudes (pro-democracy vs. pro-Beijing)', 
                  'ccp_legitimate_now' = 'Legitimacy of CCP rule in Hong Kong', 
                  'independence_attitude' = 'HK should be independent', 
                  'az_polpreferences' = 'Index of political preferences (z-score)',
                  'independence_afraid' = 'Others afraid of expressing pro-independence views', 
                  'sec_democracy_nodiff_hk' = 'Second-order beliefs about importance of democracy', 
                  'sec_ccp_legitimate_hk' = 'Second-order beliefs about legitimacy of CCP rule in Hong Kong', 
                  'sec_indep_attitude_hk' = 'Second-order beliefs about whether HK should be independent', 
                  'az_secbeliefs' = 'Index of second-order beliefs (z-score)')
  pvalues$outcome = rep(names(outcomes)[c(1:4, 6:9, 11:14)], 3)
  pvalues$column = c(rep(1, 12), rep(2, 12), rep(3, 12))
  collection = list()
  run_models = function(outcome) {
    savevalues = list()
    for (period in c('_post17','_pre18')) {
      outcomevar = str_interp('${outcome}${period}')
      data[,outcomevar] = data[,outcomevar] %>% unlist %>% as.numeric()
      model1 = lm(as.formula(str_interp('${outcomevar}~treatment_main')), data = data %>% filter(treatment_subway==0))
      model2 = lm(as.formula(str_interp('${outcomevar}~treatment_main+treatment_cell')), data = data %>% filter(treatment_subway==0))
      model3 = lm(as.formula(str_interp('${outcomevar}~treatment_main')), data = data %>% filter(treatment_main==1 | treatment_subway == 1))
      model4 = lm(as.formula(str_interp('${outcomevar}~treatment_main+treatment_cell')), data = data %>% filter(treatment_main==1 | treatment_subway == 1))
      model5 = lm(as.formula(str_interp('${outcomevar}~treatment_subway')), data = data %>% filter(treatment_main==0))
      model6 = lm(as.formula(str_interp('${outcomevar}~treatment_subway+treatment_cell')), data = data %>% filter(treatment_main==0))
      models = list(model1, model2, model3, model4, model5, model6)
      outcomemean = mean(data[,outcomevar] %>% unlist, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
      outcomesd = sd(data[,outcomevar]  %>% unlist, na.rm=T) %>% round(3) %>% sprintf("%.3f", .)
      extract = function(x) {
        x = tidy(x)
        return(c(x[2, 'estimate'], x[2, 'std.error'], x[2, 'p.value']))
      }
      values = map(models, extract)
      coefs = map_chr(values, function(x) x[[1]] %>% round(3) %>% sprintf("%.3f", .))
      errors = map_chr(values, function(x) x[[2]] %>% round(3) %>% sprintf("%.3f", .))
      pvals = map_chr(values, function(x) x[[3]] %>% round(3) %>% sprintf("%.3f", .))
      savevalues[[period]] = list('coefs' = coefs, 'errors' = errors, 'pvals' = pvals, 'mean' = outcomemean, 'sd' = outcomesd)
    }
    return(savevalues)
  }
  create_outcome_tex = function(outcome) {
    coll = collection[[outcome]]
    caption = str_interp('${outcomes[[outcome]]}')
    errors2017 = paste0('(', coll[['_post17']][['errors']])
    errors2017 = paste0(errors2017, ')')
    errors2018 = paste0('(', coll[['_pre18']][['errors']])
    errors2018 = paste0(errors2018, ')')
    outcomemean2017 = coll[['_post17']][['mean']]
    outcomesd2017 = coll[['_post17']][['sd']]
    outcomemean2018 = coll[['_pre18']][['mean']]
    outcomesd2018 = coll[['_pre18']][['sd']]
    upvals2017 = coll[['_post17']][['pvals']]
    upvals2018 = coll[['_pre18']][['pvals']]
    pvals = pvalues[pvalues$outcome==outcome,]
    pvals2017 = pvals$post17 %>% round(3) %>% sprintf("%.3f", .)
    pvals2018 = pvals$pre18 %>% round(3) %>% sprintf("%.3f", .)
    latex = c(str_interp('\\multicolumn{  7 }{@{} l}{Panel ${coll["letter"]}.1: \\textit{${caption}, post-July 2017}} \\\\ \\midrule'),
              paste0('Group 1 & ', paste(coll[['_post17']][['coefs']], collapse = '  & '), '\\\\'),
              paste0(' & ', paste(errors2017, collapse = '  & '), '\\\\'),
              str_interp('DV mean & ${outcomemean2017} & ${outcomemean2017} & ${outcomemean2017} & ${outcomemean2017} & ${outcomemean2017} & ${outcomemean2017} \\\\'),
              str_interp('DV std.dev. & ${outcomesd2017} & ${outcomesd2017} & ${outcomesd2017} & ${outcomesd2017} & ${outcomesd2017} & ${outcomesd2017} \\\\'),
              paste0('p-value & ', paste(coll[['_post17']][['pvals']], collapse = '  & '), '\\\\'),
              ifelse(str_detect(outcome, 'az_'), '', str_interp('Adj. p-value & ${pvals2017[1]} & - & ${pvals2017[2]} & - & ${pvals2017[3]} & - \\\\')),
              '\\midrule',
              str_interp('\\multicolumn{ 7 }{@{} l}{Panel ${coll["letter"]}.2: \\textit{${caption}, pre-July 2018}} \\\\ \\midrule'),
              paste0('Group 1 & ', paste(coll[['_pre18']][['coefs']], collapse = '  & '), '\\\\'),
              paste0(' & ', paste(errors2018, collapse = '  & '), '\\\\'),
              str_interp('DV mean & ${outcomemean2018} & ${outcomemean2018} & ${outcomemean2018} & ${outcomemean2018} & ${outcomemean2018} & ${outcomemean2018} \\\\'),
              str_interp('DV std.dev. & ${outcomesd2018} & ${outcomesd2018} & ${outcomesd2018} & ${outcomesd2018} & ${outcomesd2018} & ${outcomesd2018} \\\\'),
              paste0('p-value & ', paste(coll[['_pre18']][['pvals']], collapse = '  & '), '\\\\'),
              ifelse(str_detect(outcome, 'az_'), '', str_interp('Adj. p-value & ${pvals2018[1]} & - & ${pvals2018[2]} & - & ${pvals2018[3]} & - \\\\')),
              '\\midrule \\addlinespace[4pt] \\midrule')
    return (latex)
  }
  letter = 1
  tex = c()
  for (outcome in names(outcomes)) {
    collection[[outcome]] = run_models(outcome)
    collection[[outcome]]['letter'] = LETTERS[letter]
    tex = c(tex, create_outcome_tex(outcome))
    letter = letter+1
  }
  obs = nrow(data)
  tex = c(
    '\\begin{center}',
    '\\begin{longtable}{lcccccc}',
    '\\caption{Group effects on individual outcomes}\\\\',
    '\\label{t:full_mechanisms}\\\\',
    '\\toprule',
    '& (1) & (2) & (3) & (4) & (5) & (6) \\\\',
    '& (T-Pu) & (T-Pu, FE) & (T-Pl) & (T-Pl, FE) & (Pl-Pu) & (Pl-Pu, FE) \\\\',
    '\\endfirsthead',
    '\\multicolumn{7}{c}{{\\tablename\\ \\thetable{} -- continued from previous page.}} \\\\', 
    '\\midrule',
    '& (1) & (2) & (3) & (4) & (5) & (6) \\\\',
    '& (T-Pu) & (T-Pu, FE) & (T-Pl) & (T-Pl, FE) & (Pl-Pu) & (Pl-Pu, FE) \\\\',
    '\\toprule', 
    '\\endhead',
    '\\bottomrule \\multicolumn{7}{c}{\\itshape Continued on next page.}',
    '\\endfoot',
    '\\bottomrule',
    '\\endlastfoot',
    '\\toprule',
    tex[1:(length(tex)-1)],
    '\\midrule',
    'Treatment cell FEs & No & Yes & No & Yes & No & Yes \\\\',
    str_interp('Observations & ${obs} & ${obs} & ${obs} & ${obs} & ${obs} & ${obs} \\\\'),
    '\\bottomrule',
    '\\multicolumn{7}{p{0.88\\textwidth}}{\\footnotesize \\textit{Notes:} Table reports estimated coefficients from regressions of each outcome on an indicator for the first condition in the column heading (the main treatment in Columns 1-4 and the placebo in Columns 5-6), in which the sample is limited to the two conditions listed in the column heading (treatment and pure control in Columns 1-2, treatment and placebo in Columns 3-4, and placebo and pure control in Columns 5-6). Columns 2, 4, and 6 include controls for a full set of treatment cell fixed effects. We present p-values adjusted for multiple hypothesis testing following \\citet{enikolopovmp2016} at the level of each of the three broad categories within each period (post-17 and pre-18) and at the level of each of the three broad categories (political beliefs, political preferences, and political beliefs about other Hong Kong citizens).}',
    '\\end{longtable}',
    '\\end{center}'
  )
  writeLines(tex, con = 'minimal/individual-outcome-table.tex')
}

data = read_dta('data/working/minimal.dta')
pvalues = read_csv('minimal/MHT_P_Values.txt')
make_outcomes_table(data)
